/**
 * New user popup.
 * @param {jQuery} $ - jQuery.
 * @author pcichosz
 */
var PhqNewUser = (function($) {

	var _phqNewUser = {

		events: {

			/**
			 * Inits tinyMCE and update page height.
			 * @param {String} id - Id of textarea (without hash).
			 * @param {jQuery} popup - Popup handler with form.
			 * @author pcichosz
			 */
			initTinyMCE: function(id, popup) {
				var proofMsgTpl = popup.find('#'+ id);
				if (proofMsgTpl.length === 1) {
					initTinyMCE('message_new_user', {
						oninit: function() {
							popups.removeOverlay();
							updatePage();
							popups.showOverlay();
						}
					});
				}
			},

			/**
			 * Inits more settings section.
			 * @param {jQuery} popup - Popup handler with form.
			 * @author pcichosz
			 */
			initMoreSettings: function(popup) {
				var settingsSection = popup.find('#more_settings_section');
				if (settingsSection.length === 1) {
					var moreSettingsObj = new MoreSettings();
					moreSettingsObj.parentHandler = popup;
					moreSettingsObj.handler = settingsSection;
					moreSettingsObj._init();
				}
			},

			/**
			 * Checks proper credentials for account.
			 * @param {jQuery} popup - Popup handler with form.
			 * @author pcichosz
			 */
			initCheckAccountCredentials: function(popup) {
				var credentialsSelect = popup.find('#credential_id');
				var link = baseurl + '/account/getCredentialsForSelect';

				popup.find('#account_id').change(function() {
				
					$.post(link, {account_id : $(this).val()}, function(data) {
						var hasError = parseInt(data.error, 10) === 1;
						if (hasError) {
							if (data.credentials.length === 0) {
								data.credentials = {0 : __('No permission profiles')};
							}
						}
						credentialsSelect
							.html('')
							.setOptions(data.credentials).val(data.selected)
							.updateCustomSelect();

					}, 'json')
				});
			},

			/**
			 * Checks if email is correct.
			 * @param {jQuery} popup - Popup handler with form.
			 * @author pcichosz
			 */
			initCheckEmail: function(popup) {
				var emailField = popup.find('#email');

				emailField.blur(function() {
					var emailFieldValue = $(this).val();
					var params = {
						email: emailFieldValue
					};
					params.type = PhqNewItem.USER_TYPES[PhqNewItem.USER_TYPE];
					$.post(baseurl + '/account/validateUserEmail', params, function(data) {
		        var hasError = parseInt(data.error, 10) === 1;
		        PhqNewItem.errors.hide();
		        if(hasError) {
		        	PhqNewItem.errors.show(data.errors);
		        }
					}, 'json');
				});
			}
		}

	};

	return {
		showPopup: function(options) {

	    if (typeof options === 'undefined') {
				options = {};
	    }

	    // For list view.
	    if (typeof oListaPage !== 'undefined') {
	      if (typeof oListaPage.getComponentsByClassName === 'function') {
		      var components = oListaPage.getComponentsByClassName('ViewsContactTable');
		      if (components[0]) {
		        var oListTable = components[0];
		        oListTable.submenuHideCloseExcept();
		      }
		    }
	    }

	    $('#sidebar_buttons > div').removeClass('selected');
	    $('#left_sidebar #sidebar_buttons .js-show-submenu').removeClass('active');
	    $('#drobpox_send_button').removeClass('active');

			var link = typeof options.link === 'undefined' ? baseurl + '/newuser?type=new&replace_submit=1' : options.link;
			var redirect = typeof options.redirect === 'undefined' ? false : options.redirect;

			PhqNewItem.showPopup({
				link: link,
				redirect: redirect,
				onInit: function(popup) {
					_phqNewUser.events.initCheckAccountCredentials(popup);
					_phqNewUser.events.initTinyMCE('message_new_user', popup);
					_phqNewUser.events.initMoreSettings(popup);
					//_phqNewUser.events.initCheckEmail(popup);
				}
			});

		}
	};

})(jQuery);